@@ -26,9 +26,9 @@
 7                反白显示
 8                不可见
 """
-import asyncio
+import sys
 import datetime
-import random
+import os
 from functools import wraps
 import time
 
@@ -49,6 +49,7 @@ def logit(func):
         return result
     return with_logging
 
+
 def async_logit(func):
     @wraps(func)
     async def with_logging(*args, **kwargs):
@@ -61,3 +62,6 @@ def async_logit(func):
     return with_logging
 
 
+def conlog(msg):
+    date = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+    print(f'\033[1;31m {date} \033[0m - \033[4;33m{os.path.basename(__file__)}\033[0m -\033[1;35m 位置:{sys._getframe().f_lineno}\033[0m - \033[0;32m{msg}\033[0m')
