@@ -364,7 +364,7 @@ def monitoring_run_time(f):
     return wrapper
 
 
-def judge_time(ti: str, st: str, en: str):
+def judge_time(ti: str, st: str, en: str, year:bool=True):
     """
     字段格式：0000-00-00 00:00:00
     判断时间ti是否在be和en之间，返回True或False
@@ -373,9 +373,14 @@ def judge_time(ti: str, st: str, en: str):
     :param en: 范围结束时间
     :return: True or  False
     """
-    d_time_st = datetime.datetime.strptime(ti, '%Y-%m-%d %H:%M:%S')
-    d_time_en = datetime.datetime.strptime(st, '%Y-%m-%d %H:%M:%S')
-    n_time = datetime.datetime.strptime(en, '%Y-%m-%d %H:%M:%S')
+    if year:
+        d_time_st = datetime.datetime.strptime(ti, '%Y-%m-%d %H:%M:%S')
+        d_time_en = datetime.datetime.strptime(st, '%Y-%m-%d %H:%M:%S')
+        n_time = datetime.datetime.strptime(en, '%Y-%m-%d %H:%M:%S')
+    else:
+        d_time_st = datetime.datetime.strptime(ti, '%H:%M:%S')
+        d_time_en = datetime.datetime.strptime(st, '%H:%M:%S')
+        n_time = datetime.datetime.strptime(en, '%H:%M:%S')
     assert d_time_en > d_time_st, "时间范围需结束时间大于开始时间！"
     if n_time > d_time_st and n_time < d_time_en:
         return True
